# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['DeviceGroupArgs', 'DeviceGroup']

@pulumi.input_type
class DeviceGroupArgs:
    def __init__(__self__, *,
                 auto_sync: Optional[pulumi.Input[_builtins.str]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 devices: Optional[pulumi.Input[Sequence[pulumi.Input['DeviceGroupDeviceArgs']]]] = None,
                 full_load_on_sync: Optional[pulumi.Input[_builtins.str]] = None,
                 incremental_config: Optional[pulumi.Input[_builtins.int]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 network_failover: Optional[pulumi.Input[_builtins.str]] = None,
                 partition: Optional[pulumi.Input[_builtins.str]] = None,
                 save_on_auto_sync: Optional[pulumi.Input[_builtins.str]] = None,
                 type: Optional[pulumi.Input[_builtins.str]] = None):
        """
        The set of arguments for constructing a DeviceGroup resource.
        :param pulumi.Input[_builtins.str] auto_sync: Specifies if the device-group will automatically sync configuration data to its members
        :param pulumi.Input[_builtins.str] description: Description of Device group
        :param pulumi.Input[Sequence[pulumi.Input['DeviceGroupDeviceArgs']]] devices: Name of the device to be included in device group, this need to be configured before using devicegroup resource
        :param pulumi.Input[_builtins.str] full_load_on_sync: Specifies if the device-group will perform a full-load upon sync
        :param pulumi.Input[_builtins.int] incremental_config: Specifies the maximum size (in KB) to devote to incremental config sync cached transactions. The default is 1024 KB.
        :param pulumi.Input[_builtins.str] name: Is the name of the device Group
        :param pulumi.Input[_builtins.str] network_failover: Specifies if the device-group will use a network connection for failover
        :param pulumi.Input[_builtins.str] partition: Device administrative partition
        :param pulumi.Input[_builtins.str] save_on_auto_sync: Specifies whether the configuration should be saved upon auto-sync.
        :param pulumi.Input[_builtins.str] type: Specifies if the device-group will be used for failover or resource syncing
        """
        if auto_sync is not None:
            pulumi.set(__self__, "auto_sync", auto_sync)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if devices is not None:
            pulumi.set(__self__, "devices", devices)
        if full_load_on_sync is not None:
            pulumi.set(__self__, "full_load_on_sync", full_load_on_sync)
        if incremental_config is not None:
            pulumi.set(__self__, "incremental_config", incremental_config)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if network_failover is not None:
            pulumi.set(__self__, "network_failover", network_failover)
        if partition is not None:
            pulumi.set(__self__, "partition", partition)
        if save_on_auto_sync is not None:
            pulumi.set(__self__, "save_on_auto_sync", save_on_auto_sync)
        if type is not None:
            pulumi.set(__self__, "type", type)

    @_builtins.property
    @pulumi.getter(name="autoSync")
    def auto_sync(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Specifies if the device-group will automatically sync configuration data to its members
        """
        return pulumi.get(self, "auto_sync")

    @auto_sync.setter
    def auto_sync(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "auto_sync", value)

    @_builtins.property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Description of Device group
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "description", value)

    @_builtins.property
    @pulumi.getter
    def devices(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['DeviceGroupDeviceArgs']]]]:
        """
        Name of the device to be included in device group, this need to be configured before using devicegroup resource
        """
        return pulumi.get(self, "devices")

    @devices.setter
    def devices(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['DeviceGroupDeviceArgs']]]]):
        pulumi.set(self, "devices", value)

    @_builtins.property
    @pulumi.getter(name="fullLoadOnSync")
    def full_load_on_sync(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Specifies if the device-group will perform a full-load upon sync
        """
        return pulumi.get(self, "full_load_on_sync")

    @full_load_on_sync.setter
    def full_load_on_sync(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "full_load_on_sync", value)

    @_builtins.property
    @pulumi.getter(name="incrementalConfig")
    def incremental_config(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Specifies the maximum size (in KB) to devote to incremental config sync cached transactions. The default is 1024 KB.
        """
        return pulumi.get(self, "incremental_config")

    @incremental_config.setter
    def incremental_config(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "incremental_config", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Is the name of the device Group
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter(name="networkFailover")
    def network_failover(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Specifies if the device-group will use a network connection for failover
        """
        return pulumi.get(self, "network_failover")

    @network_failover.setter
    def network_failover(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "network_failover", value)

    @_builtins.property
    @pulumi.getter
    def partition(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Device administrative partition
        """
        return pulumi.get(self, "partition")

    @partition.setter
    def partition(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "partition", value)

    @_builtins.property
    @pulumi.getter(name="saveOnAutoSync")
    def save_on_auto_sync(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Specifies whether the configuration should be saved upon auto-sync.
        """
        return pulumi.get(self, "save_on_auto_sync")

    @save_on_auto_sync.setter
    def save_on_auto_sync(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "save_on_auto_sync", value)

    @_builtins.property
    @pulumi.getter
    def type(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Specifies if the device-group will be used for failover or resource syncing
        """
        return pulumi.get(self, "type")

    @type.setter
    def type(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "type", value)


@pulumi.input_type
class _DeviceGroupState:
    def __init__(__self__, *,
                 auto_sync: Optional[pulumi.Input[_builtins.str]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 devices: Optional[pulumi.Input[Sequence[pulumi.Input['DeviceGroupDeviceArgs']]]] = None,
                 full_load_on_sync: Optional[pulumi.Input[_builtins.str]] = None,
                 incremental_config: Optional[pulumi.Input[_builtins.int]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 network_failover: Optional[pulumi.Input[_builtins.str]] = None,
                 partition: Optional[pulumi.Input[_builtins.str]] = None,
                 save_on_auto_sync: Optional[pulumi.Input[_builtins.str]] = None,
                 type: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering DeviceGroup resources.
        :param pulumi.Input[_builtins.str] auto_sync: Specifies if the device-group will automatically sync configuration data to its members
        :param pulumi.Input[_builtins.str] description: Description of Device group
        :param pulumi.Input[Sequence[pulumi.Input['DeviceGroupDeviceArgs']]] devices: Name of the device to be included in device group, this need to be configured before using devicegroup resource
        :param pulumi.Input[_builtins.str] full_load_on_sync: Specifies if the device-group will perform a full-load upon sync
        :param pulumi.Input[_builtins.int] incremental_config: Specifies the maximum size (in KB) to devote to incremental config sync cached transactions. The default is 1024 KB.
        :param pulumi.Input[_builtins.str] name: Is the name of the device Group
        :param pulumi.Input[_builtins.str] network_failover: Specifies if the device-group will use a network connection for failover
        :param pulumi.Input[_builtins.str] partition: Device administrative partition
        :param pulumi.Input[_builtins.str] save_on_auto_sync: Specifies whether the configuration should be saved upon auto-sync.
        :param pulumi.Input[_builtins.str] type: Specifies if the device-group will be used for failover or resource syncing
        """
        if auto_sync is not None:
            pulumi.set(__self__, "auto_sync", auto_sync)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if devices is not None:
            pulumi.set(__self__, "devices", devices)
        if full_load_on_sync is not None:
            pulumi.set(__self__, "full_load_on_sync", full_load_on_sync)
        if incremental_config is not None:
            pulumi.set(__self__, "incremental_config", incremental_config)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if network_failover is not None:
            pulumi.set(__self__, "network_failover", network_failover)
        if partition is not None:
            pulumi.set(__self__, "partition", partition)
        if save_on_auto_sync is not None:
            pulumi.set(__self__, "save_on_auto_sync", save_on_auto_sync)
        if type is not None:
            pulumi.set(__self__, "type", type)

    @_builtins.property
    @pulumi.getter(name="autoSync")
    def auto_sync(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Specifies if the device-group will automatically sync configuration data to its members
        """
        return pulumi.get(self, "auto_sync")

    @auto_sync.setter
    def auto_sync(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "auto_sync", value)

    @_builtins.property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Description of Device group
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "description", value)

    @_builtins.property
    @pulumi.getter
    def devices(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['DeviceGroupDeviceArgs']]]]:
        """
        Name of the device to be included in device group, this need to be configured before using devicegroup resource
        """
        return pulumi.get(self, "devices")

    @devices.setter
    def devices(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['DeviceGroupDeviceArgs']]]]):
        pulumi.set(self, "devices", value)

    @_builtins.property
    @pulumi.getter(name="fullLoadOnSync")
    def full_load_on_sync(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Specifies if the device-group will perform a full-load upon sync
        """
        return pulumi.get(self, "full_load_on_sync")

    @full_load_on_sync.setter
    def full_load_on_sync(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "full_load_on_sync", value)

    @_builtins.property
    @pulumi.getter(name="incrementalConfig")
    def incremental_config(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Specifies the maximum size (in KB) to devote to incremental config sync cached transactions. The default is 1024 KB.
        """
        return pulumi.get(self, "incremental_config")

    @incremental_config.setter
    def incremental_config(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "incremental_config", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Is the name of the device Group
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter(name="networkFailover")
    def network_failover(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Specifies if the device-group will use a network connection for failover
        """
        return pulumi.get(self, "network_failover")

    @network_failover.setter
    def network_failover(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "network_failover", value)

    @_builtins.property
    @pulumi.getter
    def partition(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Device administrative partition
        """
        return pulumi.get(self, "partition")

    @partition.setter
    def partition(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "partition", value)

    @_builtins.property
    @pulumi.getter(name="saveOnAutoSync")
    def save_on_auto_sync(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Specifies whether the configuration should be saved upon auto-sync.
        """
        return pulumi.get(self, "save_on_auto_sync")

    @save_on_auto_sync.setter
    def save_on_auto_sync(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "save_on_auto_sync", value)

    @_builtins.property
    @pulumi.getter
    def type(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Specifies if the device-group will be used for failover or resource syncing
        """
        return pulumi.get(self, "type")

    @type.setter
    def type(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "type", value)


@pulumi.type_token("f5bigip:cm/deviceGroup:DeviceGroup")
class DeviceGroup(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 auto_sync: Optional[pulumi.Input[_builtins.str]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 devices: Optional[pulumi.Input[Sequence[pulumi.Input[Union['DeviceGroupDeviceArgs', 'DeviceGroupDeviceArgsDict']]]]] = None,
                 full_load_on_sync: Optional[pulumi.Input[_builtins.str]] = None,
                 incremental_config: Optional[pulumi.Input[_builtins.int]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 network_failover: Optional[pulumi.Input[_builtins.str]] = None,
                 partition: Optional[pulumi.Input[_builtins.str]] = None,
                 save_on_auto_sync: Optional[pulumi.Input[_builtins.str]] = None,
                 type: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        `cm.DeviceGroup` A device group is a collection of BIG-IP devices that are configured to securely synchronize their BIG-IP configuration data, and fail over when needed.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_f5bigip as f5bigip

        my_new_devicegroup = f5bigip.cm.DeviceGroup("my_new_devicegroup",
            name="sanjose_devicegroup",
            auto_sync="enabled",
            full_load_on_sync="true",
            type="sync-only",
            devices=[
                {
                    "name": "bigip1.cisco.com",
                },
                {
                    "name": "bigip200.f5.com",
                },
            ])
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] auto_sync: Specifies if the device-group will automatically sync configuration data to its members
        :param pulumi.Input[_builtins.str] description: Description of Device group
        :param pulumi.Input[Sequence[pulumi.Input[Union['DeviceGroupDeviceArgs', 'DeviceGroupDeviceArgsDict']]]] devices: Name of the device to be included in device group, this need to be configured before using devicegroup resource
        :param pulumi.Input[_builtins.str] full_load_on_sync: Specifies if the device-group will perform a full-load upon sync
        :param pulumi.Input[_builtins.int] incremental_config: Specifies the maximum size (in KB) to devote to incremental config sync cached transactions. The default is 1024 KB.
        :param pulumi.Input[_builtins.str] name: Is the name of the device Group
        :param pulumi.Input[_builtins.str] network_failover: Specifies if the device-group will use a network connection for failover
        :param pulumi.Input[_builtins.str] partition: Device administrative partition
        :param pulumi.Input[_builtins.str] save_on_auto_sync: Specifies whether the configuration should be saved upon auto-sync.
        :param pulumi.Input[_builtins.str] type: Specifies if the device-group will be used for failover or resource syncing
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: Optional[DeviceGroupArgs] = None,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        `cm.DeviceGroup` A device group is a collection of BIG-IP devices that are configured to securely synchronize their BIG-IP configuration data, and fail over when needed.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_f5bigip as f5bigip

        my_new_devicegroup = f5bigip.cm.DeviceGroup("my_new_devicegroup",
            name="sanjose_devicegroup",
            auto_sync="enabled",
            full_load_on_sync="true",
            type="sync-only",
            devices=[
                {
                    "name": "bigip1.cisco.com",
                },
                {
                    "name": "bigip200.f5.com",
                },
            ])
        ```

        :param str resource_name: The name of the resource.
        :param DeviceGroupArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(DeviceGroupArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 auto_sync: Optional[pulumi.Input[_builtins.str]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 devices: Optional[pulumi.Input[Sequence[pulumi.Input[Union['DeviceGroupDeviceArgs', 'DeviceGroupDeviceArgsDict']]]]] = None,
                 full_load_on_sync: Optional[pulumi.Input[_builtins.str]] = None,
                 incremental_config: Optional[pulumi.Input[_builtins.int]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 network_failover: Optional[pulumi.Input[_builtins.str]] = None,
                 partition: Optional[pulumi.Input[_builtins.str]] = None,
                 save_on_auto_sync: Optional[pulumi.Input[_builtins.str]] = None,
                 type: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = DeviceGroupArgs.__new__(DeviceGroupArgs)

            __props__.__dict__["auto_sync"] = auto_sync
            __props__.__dict__["description"] = description
            __props__.__dict__["devices"] = devices
            __props__.__dict__["full_load_on_sync"] = full_load_on_sync
            __props__.__dict__["incremental_config"] = incremental_config
            __props__.__dict__["name"] = name
            __props__.__dict__["network_failover"] = network_failover
            __props__.__dict__["partition"] = partition
            __props__.__dict__["save_on_auto_sync"] = save_on_auto_sync
            __props__.__dict__["type"] = type
        super(DeviceGroup, __self__).__init__(
            'f5bigip:cm/deviceGroup:DeviceGroup',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            auto_sync: Optional[pulumi.Input[_builtins.str]] = None,
            description: Optional[pulumi.Input[_builtins.str]] = None,
            devices: Optional[pulumi.Input[Sequence[pulumi.Input[Union['DeviceGroupDeviceArgs', 'DeviceGroupDeviceArgsDict']]]]] = None,
            full_load_on_sync: Optional[pulumi.Input[_builtins.str]] = None,
            incremental_config: Optional[pulumi.Input[_builtins.int]] = None,
            name: Optional[pulumi.Input[_builtins.str]] = None,
            network_failover: Optional[pulumi.Input[_builtins.str]] = None,
            partition: Optional[pulumi.Input[_builtins.str]] = None,
            save_on_auto_sync: Optional[pulumi.Input[_builtins.str]] = None,
            type: Optional[pulumi.Input[_builtins.str]] = None) -> 'DeviceGroup':
        """
        Get an existing DeviceGroup resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] auto_sync: Specifies if the device-group will automatically sync configuration data to its members
        :param pulumi.Input[_builtins.str] description: Description of Device group
        :param pulumi.Input[Sequence[pulumi.Input[Union['DeviceGroupDeviceArgs', 'DeviceGroupDeviceArgsDict']]]] devices: Name of the device to be included in device group, this need to be configured before using devicegroup resource
        :param pulumi.Input[_builtins.str] full_load_on_sync: Specifies if the device-group will perform a full-load upon sync
        :param pulumi.Input[_builtins.int] incremental_config: Specifies the maximum size (in KB) to devote to incremental config sync cached transactions. The default is 1024 KB.
        :param pulumi.Input[_builtins.str] name: Is the name of the device Group
        :param pulumi.Input[_builtins.str] network_failover: Specifies if the device-group will use a network connection for failover
        :param pulumi.Input[_builtins.str] partition: Device administrative partition
        :param pulumi.Input[_builtins.str] save_on_auto_sync: Specifies whether the configuration should be saved upon auto-sync.
        :param pulumi.Input[_builtins.str] type: Specifies if the device-group will be used for failover or resource syncing
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _DeviceGroupState.__new__(_DeviceGroupState)

        __props__.__dict__["auto_sync"] = auto_sync
        __props__.__dict__["description"] = description
        __props__.__dict__["devices"] = devices
        __props__.__dict__["full_load_on_sync"] = full_load_on_sync
        __props__.__dict__["incremental_config"] = incremental_config
        __props__.__dict__["name"] = name
        __props__.__dict__["network_failover"] = network_failover
        __props__.__dict__["partition"] = partition
        __props__.__dict__["save_on_auto_sync"] = save_on_auto_sync
        __props__.__dict__["type"] = type
        return DeviceGroup(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="autoSync")
    def auto_sync(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Specifies if the device-group will automatically sync configuration data to its members
        """
        return pulumi.get(self, "auto_sync")

    @_builtins.property
    @pulumi.getter
    def description(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Description of Device group
        """
        return pulumi.get(self, "description")

    @_builtins.property
    @pulumi.getter
    def devices(self) -> pulumi.Output[Optional[Sequence['outputs.DeviceGroupDevice']]]:
        """
        Name of the device to be included in device group, this need to be configured before using devicegroup resource
        """
        return pulumi.get(self, "devices")

    @_builtins.property
    @pulumi.getter(name="fullLoadOnSync")
    def full_load_on_sync(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Specifies if the device-group will perform a full-load upon sync
        """
        return pulumi.get(self, "full_load_on_sync")

    @_builtins.property
    @pulumi.getter(name="incrementalConfig")
    def incremental_config(self) -> pulumi.Output[Optional[_builtins.int]]:
        """
        Specifies the maximum size (in KB) to devote to incremental config sync cached transactions. The default is 1024 KB.
        """
        return pulumi.get(self, "incremental_config")

    @_builtins.property
    @pulumi.getter
    def name(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Is the name of the device Group
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter(name="networkFailover")
    def network_failover(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Specifies if the device-group will use a network connection for failover
        """
        return pulumi.get(self, "network_failover")

    @_builtins.property
    @pulumi.getter
    def partition(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Device administrative partition
        """
        return pulumi.get(self, "partition")

    @_builtins.property
    @pulumi.getter(name="saveOnAutoSync")
    def save_on_auto_sync(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Specifies whether the configuration should be saved upon auto-sync.
        """
        return pulumi.get(self, "save_on_auto_sync")

    @_builtins.property
    @pulumi.getter
    def type(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Specifies if the device-group will be used for failover or resource syncing
        """
        return pulumi.get(self, "type")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['OcspArgs', 'Ocsp']

@pulumi.input_type
class OcspArgs:
    def __init__(__self__, *,
                 name: pulumi.Input[_builtins.str],
                 cache_error_timeout: Optional[pulumi.Input[_builtins.int]] = None,
                 cache_timeout: Optional[pulumi.Input[_builtins.str]] = None,
                 clock_skew: Optional[pulumi.Input[_builtins.int]] = None,
                 concurrent_connections_limit: Optional[pulumi.Input[_builtins.int]] = None,
                 connection_timeout: Optional[pulumi.Input[_builtins.int]] = None,
                 dns_resolver: Optional[pulumi.Input[_builtins.str]] = None,
                 passphrase: Optional[pulumi.Input[_builtins.str]] = None,
                 proxy_server_pool: Optional[pulumi.Input[_builtins.str]] = None,
                 responder_url: Optional[pulumi.Input[_builtins.str]] = None,
                 route_domain: Optional[pulumi.Input[_builtins.str]] = None,
                 sign_hash: Optional[pulumi.Input[_builtins.str]] = None,
                 signer_cert: Optional[pulumi.Input[_builtins.str]] = None,
                 signer_key: Optional[pulumi.Input[_builtins.str]] = None,
                 status_age: Optional[pulumi.Input[_builtins.int]] = None,
                 strict_resp_cert_check: Optional[pulumi.Input[_builtins.str]] = None,
                 trusted_responders: Optional[pulumi.Input[_builtins.str]] = None):
        """
        The set of arguments for constructing a Ocsp resource.
        :param pulumi.Input[_builtins.str] name: Name of the OCSP Responder. Name should be in pattern `/partition/ocsp_name`.
        :param pulumi.Input[_builtins.int] cache_error_timeout: Specifies the lifetime of an error response in the cache, in seconds. This value must be greater than connection_timeout. The default value is `3600`.
        :param pulumi.Input[_builtins.str] cache_timeout: Specifies the lifetime of the OCSP response in the cache, in seconds. The default value is `indefinite`.
        :param pulumi.Input[_builtins.int] clock_skew: Specifies the time interval that the BIG-IP system allows for clock skew, in seconds. The default value is `300`.
        :param pulumi.Input[_builtins.int] concurrent_connections_limit: Specifies the maximum number of connections per second allowed for the OCSP certificate validator. The default value is `50`.
        :param pulumi.Input[_builtins.int] connection_timeout: Specifies the time interval that the BIG-IP system waits for before ending the connection to the OCSP responder, in seconds. The default value is `8`.
        :param pulumi.Input[_builtins.str] dns_resolver: Specifies the internal DNS resolver the BIG-IP system uses to fetch the OCSP response.
        :param pulumi.Input[_builtins.str] passphrase: Specifies a passphrase used to sign an OCSP request.
        :param pulumi.Input[_builtins.str] proxy_server_pool: Specifies the proxy server pool the BIG-IP system uses to fetch the OCSP response.
        :param pulumi.Input[_builtins.str] responder_url: Specifies the URL of the OCSP responder.
        :param pulumi.Input[_builtins.str] route_domain: Specifies the route domain for the OCSP responder.
        :param pulumi.Input[_builtins.str] sign_hash: Specifies the hash algorithm used to sign the OCSP request. The default value is `sha256`.
        :param pulumi.Input[_builtins.str] signer_cert: Specifies the certificate used to sign the OCSP request.
        :param pulumi.Input[_builtins.str] signer_key: Specifies the key used to sign the OCSP request.
        :param pulumi.Input[_builtins.int] status_age: Specifies the maximum allowed lag time that the BIG-IP system accepts for the 'thisUpdate' time in the OCSP response, in seconds. The default value is `0`.
        :param pulumi.Input[_builtins.str] strict_resp_cert_check: Specifies whether the responder's certificate is checked for an OCSP signing extension. The default value is `enabled`.
        :param pulumi.Input[_builtins.str] trusted_responders: Specifies the certificates used for validating the OCSP response.
        """
        pulumi.set(__self__, "name", name)
        if cache_error_timeout is not None:
            pulumi.set(__self__, "cache_error_timeout", cache_error_timeout)
        if cache_timeout is not None:
            pulumi.set(__self__, "cache_timeout", cache_timeout)
        if clock_skew is not None:
            pulumi.set(__self__, "clock_skew", clock_skew)
        if concurrent_connections_limit is not None:
            pulumi.set(__self__, "concurrent_connections_limit", concurrent_connections_limit)
        if connection_timeout is not None:
            pulumi.set(__self__, "connection_timeout", connection_timeout)
        if dns_resolver is not None:
            pulumi.set(__self__, "dns_resolver", dns_resolver)
        if passphrase is not None:
            pulumi.set(__self__, "passphrase", passphrase)
        if proxy_server_pool is not None:
            pulumi.set(__self__, "proxy_server_pool", proxy_server_pool)
        if responder_url is not None:
            pulumi.set(__self__, "responder_url", responder_url)
        if route_domain is not None:
            pulumi.set(__self__, "route_domain", route_domain)
        if sign_hash is not None:
            pulumi.set(__self__, "sign_hash", sign_hash)
        if signer_cert is not None:
            pulumi.set(__self__, "signer_cert", signer_cert)
        if signer_key is not None:
            pulumi.set(__self__, "signer_key", signer_key)
        if status_age is not None:
            pulumi.set(__self__, "status_age", status_age)
        if strict_resp_cert_check is not None:
            pulumi.set(__self__, "strict_resp_cert_check", strict_resp_cert_check)
        if trusted_responders is not None:
            pulumi.set(__self__, "trusted_responders", trusted_responders)

    @_builtins.property
    @pulumi.getter
    def name(self) -> pulumi.Input[_builtins.str]:
        """
        Name of the OCSP Responder. Name should be in pattern `/partition/ocsp_name`.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter(name="cacheErrorTimeout")
    def cache_error_timeout(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Specifies the lifetime of an error response in the cache, in seconds. This value must be greater than connection_timeout. The default value is `3600`.
        """
        return pulumi.get(self, "cache_error_timeout")

    @cache_error_timeout.setter
    def cache_error_timeout(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "cache_error_timeout", value)

    @_builtins.property
    @pulumi.getter(name="cacheTimeout")
    def cache_timeout(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Specifies the lifetime of the OCSP response in the cache, in seconds. The default value is `indefinite`.
        """
        return pulumi.get(self, "cache_timeout")

    @cache_timeout.setter
    def cache_timeout(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "cache_timeout", value)

    @_builtins.property
    @pulumi.getter(name="clockSkew")
    def clock_skew(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Specifies the time interval that the BIG-IP system allows for clock skew, in seconds. The default value is `300`.
        """
        return pulumi.get(self, "clock_skew")

    @clock_skew.setter
    def clock_skew(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "clock_skew", value)

    @_builtins.property
    @pulumi.getter(name="concurrentConnectionsLimit")
    def concurrent_connections_limit(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Specifies the maximum number of connections per second allowed for the OCSP certificate validator. The default value is `50`.
        """
        return pulumi.get(self, "concurrent_connections_limit")

    @concurrent_connections_limit.setter
    def concurrent_connections_limit(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "concurrent_connections_limit", value)

    @_builtins.property
    @pulumi.getter(name="connectionTimeout")
    def connection_timeout(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Specifies the time interval that the BIG-IP system waits for before ending the connection to the OCSP responder, in seconds. The default value is `8`.
        """
        return pulumi.get(self, "connection_timeout")

    @connection_timeout.setter
    def connection_timeout(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "connection_timeout", value)

    @_builtins.property
    @pulumi.getter(name="dnsResolver")
    def dns_resolver(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Specifies the internal DNS resolver the BIG-IP system uses to fetch the OCSP response.
        """
        return pulumi.get(self, "dns_resolver")

    @dns_resolver.setter
    def dns_resolver(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "dns_resolver", value)

    @_builtins.property
    @pulumi.getter
    def passphrase(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Specifies a passphrase used to sign an OCSP request.
        """
        return pulumi.get(self, "passphrase")

    @passphrase.setter
    def passphrase(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "passphrase", value)

    @_builtins.property
    @pulumi.getter(name="proxyServerPool")
    def proxy_server_pool(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Specifies the proxy server pool the BIG-IP system uses to fetch the OCSP response.
        """
        return pulumi.get(self, "proxy_server_pool")

    @proxy_server_pool.setter
    def proxy_server_pool(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "proxy_server_pool", value)

    @_builtins.property
    @pulumi.getter(name="responderUrl")
    def responder_url(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Specifies the URL of the OCSP responder.
        """
        return pulumi.get(self, "responder_url")

    @responder_url.setter
    def responder_url(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "responder_url", value)

    @_builtins.property
    @pulumi.getter(name="routeDomain")
    def route_domain(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Specifies the route domain for the OCSP responder.
        """
        return pulumi.get(self, "route_domain")

    @route_domain.setter
    def route_domain(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "route_domain", value)

    @_builtins.property
    @pulumi.getter(name="signHash")
    def sign_hash(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Specifies the hash algorithm used to sign the OCSP request. The default value is `sha256`.
        """
        return pulumi.get(self, "sign_hash")

    @sign_hash.setter
    def sign_hash(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "sign_hash", value)

    @_builtins.property
    @pulumi.getter(name="signerCert")
    def signer_cert(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Specifies the certificate used to sign the OCSP request.
        """
        return pulumi.get(self, "signer_cert")

    @signer_cert.setter
    def signer_cert(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "signer_cert", value)

    @_builtins.property
    @pulumi.getter(name="signerKey")
    def signer_key(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Specifies the key used to sign the OCSP request.
        """
        return pulumi.get(self, "signer_key")

    @signer_key.setter
    def signer_key(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "signer_key", value)

    @_builtins.property
    @pulumi.getter(name="statusAge")
    def status_age(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Specifies the maximum allowed lag time that the BIG-IP system accepts for the 'thisUpdate' time in the OCSP response, in seconds. The default value is `0`.
        """
        return pulumi.get(self, "status_age")

    @status_age.setter
    def status_age(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "status_age", value)

    @_builtins.property
    @pulumi.getter(name="strictRespCertCheck")
    def strict_resp_cert_check(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Specifies whether the responder's certificate is checked for an OCSP signing extension. The default value is `enabled`.
        """
        return pulumi.get(self, "strict_resp_cert_check")

    @strict_resp_cert_check.setter
    def strict_resp_cert_check(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "strict_resp_cert_check", value)

    @_builtins.property
    @pulumi.getter(name="trustedResponders")
    def trusted_responders(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Specifies the certificates used for validating the OCSP response.
        """
        return pulumi.get(self, "trusted_responders")

    @trusted_responders.setter
    def trusted_responders(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "trusted_responders", value)


@pulumi.input_type
class _OcspState:
    def __init__(__self__, *,
                 cache_error_timeout: Optional[pulumi.Input[_builtins.int]] = None,
                 cache_timeout: Optional[pulumi.Input[_builtins.str]] = None,
                 clock_skew: Optional[pulumi.Input[_builtins.int]] = None,
                 concurrent_connections_limit: Optional[pulumi.Input[_builtins.int]] = None,
                 connection_timeout: Optional[pulumi.Input[_builtins.int]] = None,
                 dns_resolver: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 passphrase: Optional[pulumi.Input[_builtins.str]] = None,
                 proxy_server_pool: Optional[pulumi.Input[_builtins.str]] = None,
                 responder_url: Optional[pulumi.Input[_builtins.str]] = None,
                 route_domain: Optional[pulumi.Input[_builtins.str]] = None,
                 sign_hash: Optional[pulumi.Input[_builtins.str]] = None,
                 signer_cert: Optional[pulumi.Input[_builtins.str]] = None,
                 signer_key: Optional[pulumi.Input[_builtins.str]] = None,
                 status_age: Optional[pulumi.Input[_builtins.int]] = None,
                 strict_resp_cert_check: Optional[pulumi.Input[_builtins.str]] = None,
                 trusted_responders: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering Ocsp resources.
        :param pulumi.Input[_builtins.int] cache_error_timeout: Specifies the lifetime of an error response in the cache, in seconds. This value must be greater than connection_timeout. The default value is `3600`.
        :param pulumi.Input[_builtins.str] cache_timeout: Specifies the lifetime of the OCSP response in the cache, in seconds. The default value is `indefinite`.
        :param pulumi.Input[_builtins.int] clock_skew: Specifies the time interval that the BIG-IP system allows for clock skew, in seconds. The default value is `300`.
        :param pulumi.Input[_builtins.int] concurrent_connections_limit: Specifies the maximum number of connections per second allowed for the OCSP certificate validator. The default value is `50`.
        :param pulumi.Input[_builtins.int] connection_timeout: Specifies the time interval that the BIG-IP system waits for before ending the connection to the OCSP responder, in seconds. The default value is `8`.
        :param pulumi.Input[_builtins.str] dns_resolver: Specifies the internal DNS resolver the BIG-IP system uses to fetch the OCSP response.
        :param pulumi.Input[_builtins.str] name: Name of the OCSP Responder. Name should be in pattern `/partition/ocsp_name`.
        :param pulumi.Input[_builtins.str] passphrase: Specifies a passphrase used to sign an OCSP request.
        :param pulumi.Input[_builtins.str] proxy_server_pool: Specifies the proxy server pool the BIG-IP system uses to fetch the OCSP response.
        :param pulumi.Input[_builtins.str] responder_url: Specifies the URL of the OCSP responder.
        :param pulumi.Input[_builtins.str] route_domain: Specifies the route domain for the OCSP responder.
        :param pulumi.Input[_builtins.str] sign_hash: Specifies the hash algorithm used to sign the OCSP request. The default value is `sha256`.
        :param pulumi.Input[_builtins.str] signer_cert: Specifies the certificate used to sign the OCSP request.
        :param pulumi.Input[_builtins.str] signer_key: Specifies the key used to sign the OCSP request.
        :param pulumi.Input[_builtins.int] status_age: Specifies the maximum allowed lag time that the BIG-IP system accepts for the 'thisUpdate' time in the OCSP response, in seconds. The default value is `0`.
        :param pulumi.Input[_builtins.str] strict_resp_cert_check: Specifies whether the responder's certificate is checked for an OCSP signing extension. The default value is `enabled`.
        :param pulumi.Input[_builtins.str] trusted_responders: Specifies the certificates used for validating the OCSP response.
        """
        if cache_error_timeout is not None:
            pulumi.set(__self__, "cache_error_timeout", cache_error_timeout)
        if cache_timeout is not None:
            pulumi.set(__self__, "cache_timeout", cache_timeout)
        if clock_skew is not None:
            pulumi.set(__self__, "clock_skew", clock_skew)
        if concurrent_connections_limit is not None:
            pulumi.set(__self__, "concurrent_connections_limit", concurrent_connections_limit)
        if connection_timeout is not None:
            pulumi.set(__self__, "connection_timeout", connection_timeout)
        if dns_resolver is not None:
            pulumi.set(__self__, "dns_resolver", dns_resolver)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if passphrase is not None:
            pulumi.set(__self__, "passphrase", passphrase)
        if proxy_server_pool is not None:
            pulumi.set(__self__, "proxy_server_pool", proxy_server_pool)
        if responder_url is not None:
            pulumi.set(__self__, "responder_url", responder_url)
        if route_domain is not None:
            pulumi.set(__self__, "route_domain", route_domain)
        if sign_hash is not None:
            pulumi.set(__self__, "sign_hash", sign_hash)
        if signer_cert is not None:
            pulumi.set(__self__, "signer_cert", signer_cert)
        if signer_key is not None:
            pulumi.set(__self__, "signer_key", signer_key)
        if status_age is not None:
            pulumi.set(__self__, "status_age", status_age)
        if strict_resp_cert_check is not None:
            pulumi.set(__self__, "strict_resp_cert_check", strict_resp_cert_check)
        if trusted_responders is not None:
            pulumi.set(__self__, "trusted_responders", trusted_responders)

    @_builtins.property
    @pulumi.getter(name="cacheErrorTimeout")
    def cache_error_timeout(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Specifies the lifetime of an error response in the cache, in seconds. This value must be greater than connection_timeout. The default value is `3600`.
        """
        return pulumi.get(self, "cache_error_timeout")

    @cache_error_timeout.setter
    def cache_error_timeout(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "cache_error_timeout", value)

    @_builtins.property
    @pulumi.getter(name="cacheTimeout")
    def cache_timeout(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Specifies the lifetime of the OCSP response in the cache, in seconds. The default value is `indefinite`.
        """
        return pulumi.get(self, "cache_timeout")

    @cache_timeout.setter
    def cache_timeout(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "cache_timeout", value)

    @_builtins.property
    @pulumi.getter(name="clockSkew")
    def clock_skew(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Specifies the time interval that the BIG-IP system allows for clock skew, in seconds. The default value is `300`.
        """
        return pulumi.get(self, "clock_skew")

    @clock_skew.setter
    def clock_skew(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "clock_skew", value)

    @_builtins.property
    @pulumi.getter(name="concurrentConnectionsLimit")
    def concurrent_connections_limit(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Specifies the maximum number of connections per second allowed for the OCSP certificate validator. The default value is `50`.
        """
        return pulumi.get(self, "concurrent_connections_limit")

    @concurrent_connections_limit.setter
    def concurrent_connections_limit(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "concurrent_connections_limit", value)

    @_builtins.property
    @pulumi.getter(name="connectionTimeout")
    def connection_timeout(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Specifies the time interval that the BIG-IP system waits for before ending the connection to the OCSP responder, in seconds. The default value is `8`.
        """
        return pulumi.get(self, "connection_timeout")

    @connection_timeout.setter
    def connection_timeout(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "connection_timeout", value)

    @_builtins.property
    @pulumi.getter(name="dnsResolver")
    def dns_resolver(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Specifies the internal DNS resolver the BIG-IP system uses to fetch the OCSP response.
        """
        return pulumi.get(self, "dns_resolver")

    @dns_resolver.setter
    def dns_resolver(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "dns_resolver", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Name of the OCSP Responder. Name should be in pattern `/partition/ocsp_name`.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter
    def passphrase(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Specifies a passphrase used to sign an OCSP request.
        """
        return pulumi.get(self, "passphrase")

    @passphrase.setter
    def passphrase(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "passphrase", value)

    @_builtins.property
    @pulumi.getter(name="proxyServerPool")
    def proxy_server_pool(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Specifies the proxy server pool the BIG-IP system uses to fetch the OCSP response.
        """
        return pulumi.get(self, "proxy_server_pool")

    @proxy_server_pool.setter
    def proxy_server_pool(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "proxy_server_pool", value)

    @_builtins.property
    @pulumi.getter(name="responderUrl")
    def responder_url(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Specifies the URL of the OCSP responder.
        """
        return pulumi.get(self, "responder_url")

    @responder_url.setter
    def responder_url(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "responder_url", value)

    @_builtins.property
    @pulumi.getter(name="routeDomain")
    def route_domain(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Specifies the route domain for the OCSP responder.
        """
        return pulumi.get(self, "route_domain")

    @route_domain.setter
    def route_domain(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "route_domain", value)

    @_builtins.property
    @pulumi.getter(name="signHash")
    def sign_hash(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Specifies the hash algorithm used to sign the OCSP request. The default value is `sha256`.
        """
        return pulumi.get(self, "sign_hash")

    @sign_hash.setter
    def sign_hash(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "sign_hash", value)

    @_builtins.property
    @pulumi.getter(name="signerCert")
    def signer_cert(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Specifies the certificate used to sign the OCSP request.
        """
        return pulumi.get(self, "signer_cert")

    @signer_cert.setter
    def signer_cert(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "signer_cert", value)

    @_builtins.property
    @pulumi.getter(name="signerKey")
    def signer_key(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Specifies the key used to sign the OCSP request.
        """
        return pulumi.get(self, "signer_key")

    @signer_key.setter
    def signer_key(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "signer_key", value)

    @_builtins.property
    @pulumi.getter(name="statusAge")
    def status_age(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Specifies the maximum allowed lag time that the BIG-IP system accepts for the 'thisUpdate' time in the OCSP response, in seconds. The default value is `0`.
        """
        return pulumi.get(self, "status_age")

    @status_age.setter
    def status_age(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "status_age", value)

    @_builtins.property
    @pulumi.getter(name="strictRespCertCheck")
    def strict_resp_cert_check(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Specifies whether the responder's certificate is checked for an OCSP signing extension. The default value is `enabled`.
        """
        return pulumi.get(self, "strict_resp_cert_check")

    @strict_resp_cert_check.setter
    def strict_resp_cert_check(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "strict_resp_cert_check", value)

    @_builtins.property
    @pulumi.getter(name="trustedResponders")
    def trusted_responders(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Specifies the certificates used for validating the OCSP response.
        """
        return pulumi.get(self, "trusted_responders")

    @trusted_responders.setter
    def trusted_responders(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "trusted_responders", value)


@pulumi.type_token("f5bigip:sys/ocsp:Ocsp")
class Ocsp(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 cache_error_timeout: Optional[pulumi.Input[_builtins.int]] = None,
                 cache_timeout: Optional[pulumi.Input[_builtins.str]] = None,
                 clock_skew: Optional[pulumi.Input[_builtins.int]] = None,
                 concurrent_connections_limit: Optional[pulumi.Input[_builtins.int]] = None,
                 connection_timeout: Optional[pulumi.Input[_builtins.int]] = None,
                 dns_resolver: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 passphrase: Optional[pulumi.Input[_builtins.str]] = None,
                 proxy_server_pool: Optional[pulumi.Input[_builtins.str]] = None,
                 responder_url: Optional[pulumi.Input[_builtins.str]] = None,
                 route_domain: Optional[pulumi.Input[_builtins.str]] = None,
                 sign_hash: Optional[pulumi.Input[_builtins.str]] = None,
                 signer_cert: Optional[pulumi.Input[_builtins.str]] = None,
                 signer_key: Optional[pulumi.Input[_builtins.str]] = None,
                 status_age: Optional[pulumi.Input[_builtins.int]] = None,
                 strict_resp_cert_check: Optional[pulumi.Input[_builtins.str]] = None,
                 trusted_responders: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        `sys.Ocsp` Manages F5 BIG-IP OCSP responder using iControl REST.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_f5bigip as f5bigip

        test_ocsp = f5bigip.sys.Ocsp("test-ocsp",
            name="/Uncommon/test-ocsp",
            proxy_server_pool="/Common/test-poolxyz",
            signer_key="/Common/le-ssl",
            signer_cert="/Common/le-ssl",
            passphrase="testabcdef")
        ```

        ## Importing

        An existing OCSP can be imported into this resource by supplying the full path name  ex : `/partition/name`
        An example is below:
        ```sh
        $ terraform import bigip_sys_ocsp.test-ocsp /Common/test-ocsp
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.int] cache_error_timeout: Specifies the lifetime of an error response in the cache, in seconds. This value must be greater than connection_timeout. The default value is `3600`.
        :param pulumi.Input[_builtins.str] cache_timeout: Specifies the lifetime of the OCSP response in the cache, in seconds. The default value is `indefinite`.
        :param pulumi.Input[_builtins.int] clock_skew: Specifies the time interval that the BIG-IP system allows for clock skew, in seconds. The default value is `300`.
        :param pulumi.Input[_builtins.int] concurrent_connections_limit: Specifies the maximum number of connections per second allowed for the OCSP certificate validator. The default value is `50`.
        :param pulumi.Input[_builtins.int] connection_timeout: Specifies the time interval that the BIG-IP system waits for before ending the connection to the OCSP responder, in seconds. The default value is `8`.
        :param pulumi.Input[_builtins.str] dns_resolver: Specifies the internal DNS resolver the BIG-IP system uses to fetch the OCSP response.
        :param pulumi.Input[_builtins.str] name: Name of the OCSP Responder. Name should be in pattern `/partition/ocsp_name`.
        :param pulumi.Input[_builtins.str] passphrase: Specifies a passphrase used to sign an OCSP request.
        :param pulumi.Input[_builtins.str] proxy_server_pool: Specifies the proxy server pool the BIG-IP system uses to fetch the OCSP response.
        :param pulumi.Input[_builtins.str] responder_url: Specifies the URL of the OCSP responder.
        :param pulumi.Input[_builtins.str] route_domain: Specifies the route domain for the OCSP responder.
        :param pulumi.Input[_builtins.str] sign_hash: Specifies the hash algorithm used to sign the OCSP request. The default value is `sha256`.
        :param pulumi.Input[_builtins.str] signer_cert: Specifies the certificate used to sign the OCSP request.
        :param pulumi.Input[_builtins.str] signer_key: Specifies the key used to sign the OCSP request.
        :param pulumi.Input[_builtins.int] status_age: Specifies the maximum allowed lag time that the BIG-IP system accepts for the 'thisUpdate' time in the OCSP response, in seconds. The default value is `0`.
        :param pulumi.Input[_builtins.str] strict_resp_cert_check: Specifies whether the responder's certificate is checked for an OCSP signing extension. The default value is `enabled`.
        :param pulumi.Input[_builtins.str] trusted_responders: Specifies the certificates used for validating the OCSP response.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: OcspArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        `sys.Ocsp` Manages F5 BIG-IP OCSP responder using iControl REST.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_f5bigip as f5bigip

        test_ocsp = f5bigip.sys.Ocsp("test-ocsp",
            name="/Uncommon/test-ocsp",
            proxy_server_pool="/Common/test-poolxyz",
            signer_key="/Common/le-ssl",
            signer_cert="/Common/le-ssl",
            passphrase="testabcdef")
        ```

        ## Importing

        An existing OCSP can be imported into this resource by supplying the full path name  ex : `/partition/name`
        An example is below:
        ```sh
        $ terraform import bigip_sys_ocsp.test-ocsp /Common/test-ocsp
        ```

        :param str resource_name: The name of the resource.
        :param OcspArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(OcspArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 cache_error_timeout: Optional[pulumi.Input[_builtins.int]] = None,
                 cache_timeout: Optional[pulumi.Input[_builtins.str]] = None,
                 clock_skew: Optional[pulumi.Input[_builtins.int]] = None,
                 concurrent_connections_limit: Optional[pulumi.Input[_builtins.int]] = None,
                 connection_timeout: Optional[pulumi.Input[_builtins.int]] = None,
                 dns_resolver: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 passphrase: Optional[pulumi.Input[_builtins.str]] = None,
                 proxy_server_pool: Optional[pulumi.Input[_builtins.str]] = None,
                 responder_url: Optional[pulumi.Input[_builtins.str]] = None,
                 route_domain: Optional[pulumi.Input[_builtins.str]] = None,
                 sign_hash: Optional[pulumi.Input[_builtins.str]] = None,
                 signer_cert: Optional[pulumi.Input[_builtins.str]] = None,
                 signer_key: Optional[pulumi.Input[_builtins.str]] = None,
                 status_age: Optional[pulumi.Input[_builtins.int]] = None,
                 strict_resp_cert_check: Optional[pulumi.Input[_builtins.str]] = None,
                 trusted_responders: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = OcspArgs.__new__(OcspArgs)

            __props__.__dict__["cache_error_timeout"] = cache_error_timeout
            __props__.__dict__["cache_timeout"] = cache_timeout
            __props__.__dict__["clock_skew"] = clock_skew
            __props__.__dict__["concurrent_connections_limit"] = concurrent_connections_limit
            __props__.__dict__["connection_timeout"] = connection_timeout
            __props__.__dict__["dns_resolver"] = dns_resolver
            if name is None and not opts.urn:
                raise TypeError("Missing required property 'name'")
            __props__.__dict__["name"] = name
            __props__.__dict__["passphrase"] = None if passphrase is None else pulumi.Output.secret(passphrase)
            __props__.__dict__["proxy_server_pool"] = proxy_server_pool
            __props__.__dict__["responder_url"] = responder_url
            __props__.__dict__["route_domain"] = route_domain
            __props__.__dict__["sign_hash"] = sign_hash
            __props__.__dict__["signer_cert"] = signer_cert
            __props__.__dict__["signer_key"] = signer_key
            __props__.__dict__["status_age"] = status_age
            __props__.__dict__["strict_resp_cert_check"] = strict_resp_cert_check
            __props__.__dict__["trusted_responders"] = trusted_responders
        secret_opts = pulumi.ResourceOptions(additional_secret_outputs=["passphrase"])
        opts = pulumi.ResourceOptions.merge(opts, secret_opts)
        super(Ocsp, __self__).__init__(
            'f5bigip:sys/ocsp:Ocsp',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            cache_error_timeout: Optional[pulumi.Input[_builtins.int]] = None,
            cache_timeout: Optional[pulumi.Input[_builtins.str]] = None,
            clock_skew: Optional[pulumi.Input[_builtins.int]] = None,
            concurrent_connections_limit: Optional[pulumi.Input[_builtins.int]] = None,
            connection_timeout: Optional[pulumi.Input[_builtins.int]] = None,
            dns_resolver: Optional[pulumi.Input[_builtins.str]] = None,
            name: Optional[pulumi.Input[_builtins.str]] = None,
            passphrase: Optional[pulumi.Input[_builtins.str]] = None,
            proxy_server_pool: Optional[pulumi.Input[_builtins.str]] = None,
            responder_url: Optional[pulumi.Input[_builtins.str]] = None,
            route_domain: Optional[pulumi.Input[_builtins.str]] = None,
            sign_hash: Optional[pulumi.Input[_builtins.str]] = None,
            signer_cert: Optional[pulumi.Input[_builtins.str]] = None,
            signer_key: Optional[pulumi.Input[_builtins.str]] = None,
            status_age: Optional[pulumi.Input[_builtins.int]] = None,
            strict_resp_cert_check: Optional[pulumi.Input[_builtins.str]] = None,
            trusted_responders: Optional[pulumi.Input[_builtins.str]] = None) -> 'Ocsp':
        """
        Get an existing Ocsp resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.int] cache_error_timeout: Specifies the lifetime of an error response in the cache, in seconds. This value must be greater than connection_timeout. The default value is `3600`.
        :param pulumi.Input[_builtins.str] cache_timeout: Specifies the lifetime of the OCSP response in the cache, in seconds. The default value is `indefinite`.
        :param pulumi.Input[_builtins.int] clock_skew: Specifies the time interval that the BIG-IP system allows for clock skew, in seconds. The default value is `300`.
        :param pulumi.Input[_builtins.int] concurrent_connections_limit: Specifies the maximum number of connections per second allowed for the OCSP certificate validator. The default value is `50`.
        :param pulumi.Input[_builtins.int] connection_timeout: Specifies the time interval that the BIG-IP system waits for before ending the connection to the OCSP responder, in seconds. The default value is `8`.
        :param pulumi.Input[_builtins.str] dns_resolver: Specifies the internal DNS resolver the BIG-IP system uses to fetch the OCSP response.
        :param pulumi.Input[_builtins.str] name: Name of the OCSP Responder. Name should be in pattern `/partition/ocsp_name`.
        :param pulumi.Input[_builtins.str] passphrase: Specifies a passphrase used to sign an OCSP request.
        :param pulumi.Input[_builtins.str] proxy_server_pool: Specifies the proxy server pool the BIG-IP system uses to fetch the OCSP response.
        :param pulumi.Input[_builtins.str] responder_url: Specifies the URL of the OCSP responder.
        :param pulumi.Input[_builtins.str] route_domain: Specifies the route domain for the OCSP responder.
        :param pulumi.Input[_builtins.str] sign_hash: Specifies the hash algorithm used to sign the OCSP request. The default value is `sha256`.
        :param pulumi.Input[_builtins.str] signer_cert: Specifies the certificate used to sign the OCSP request.
        :param pulumi.Input[_builtins.str] signer_key: Specifies the key used to sign the OCSP request.
        :param pulumi.Input[_builtins.int] status_age: Specifies the maximum allowed lag time that the BIG-IP system accepts for the 'thisUpdate' time in the OCSP response, in seconds. The default value is `0`.
        :param pulumi.Input[_builtins.str] strict_resp_cert_check: Specifies whether the responder's certificate is checked for an OCSP signing extension. The default value is `enabled`.
        :param pulumi.Input[_builtins.str] trusted_responders: Specifies the certificates used for validating the OCSP response.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _OcspState.__new__(_OcspState)

        __props__.__dict__["cache_error_timeout"] = cache_error_timeout
        __props__.__dict__["cache_timeout"] = cache_timeout
        __props__.__dict__["clock_skew"] = clock_skew
        __props__.__dict__["concurrent_connections_limit"] = concurrent_connections_limit
        __props__.__dict__["connection_timeout"] = connection_timeout
        __props__.__dict__["dns_resolver"] = dns_resolver
        __props__.__dict__["name"] = name
        __props__.__dict__["passphrase"] = passphrase
        __props__.__dict__["proxy_server_pool"] = proxy_server_pool
        __props__.__dict__["responder_url"] = responder_url
        __props__.__dict__["route_domain"] = route_domain
        __props__.__dict__["sign_hash"] = sign_hash
        __props__.__dict__["signer_cert"] = signer_cert
        __props__.__dict__["signer_key"] = signer_key
        __props__.__dict__["status_age"] = status_age
        __props__.__dict__["strict_resp_cert_check"] = strict_resp_cert_check
        __props__.__dict__["trusted_responders"] = trusted_responders
        return Ocsp(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="cacheErrorTimeout")
    def cache_error_timeout(self) -> pulumi.Output[Optional[_builtins.int]]:
        """
        Specifies the lifetime of an error response in the cache, in seconds. This value must be greater than connection_timeout. The default value is `3600`.
        """
        return pulumi.get(self, "cache_error_timeout")

    @_builtins.property
    @pulumi.getter(name="cacheTimeout")
    def cache_timeout(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Specifies the lifetime of the OCSP response in the cache, in seconds. The default value is `indefinite`.
        """
        return pulumi.get(self, "cache_timeout")

    @_builtins.property
    @pulumi.getter(name="clockSkew")
    def clock_skew(self) -> pulumi.Output[Optional[_builtins.int]]:
        """
        Specifies the time interval that the BIG-IP system allows for clock skew, in seconds. The default value is `300`.
        """
        return pulumi.get(self, "clock_skew")

    @_builtins.property
    @pulumi.getter(name="concurrentConnectionsLimit")
    def concurrent_connections_limit(self) -> pulumi.Output[Optional[_builtins.int]]:
        """
        Specifies the maximum number of connections per second allowed for the OCSP certificate validator. The default value is `50`.
        """
        return pulumi.get(self, "concurrent_connections_limit")

    @_builtins.property
    @pulumi.getter(name="connectionTimeout")
    def connection_timeout(self) -> pulumi.Output[Optional[_builtins.int]]:
        """
        Specifies the time interval that the BIG-IP system waits for before ending the connection to the OCSP responder, in seconds. The default value is `8`.
        """
        return pulumi.get(self, "connection_timeout")

    @_builtins.property
    @pulumi.getter(name="dnsResolver")
    def dns_resolver(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Specifies the internal DNS resolver the BIG-IP system uses to fetch the OCSP response.
        """
        return pulumi.get(self, "dns_resolver")

    @_builtins.property
    @pulumi.getter
    def name(self) -> pulumi.Output[_builtins.str]:
        """
        Name of the OCSP Responder. Name should be in pattern `/partition/ocsp_name`.
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter
    def passphrase(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Specifies a passphrase used to sign an OCSP request.
        """
        return pulumi.get(self, "passphrase")

    @_builtins.property
    @pulumi.getter(name="proxyServerPool")
    def proxy_server_pool(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Specifies the proxy server pool the BIG-IP system uses to fetch the OCSP response.
        """
        return pulumi.get(self, "proxy_server_pool")

    @_builtins.property
    @pulumi.getter(name="responderUrl")
    def responder_url(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Specifies the URL of the OCSP responder.
        """
        return pulumi.get(self, "responder_url")

    @_builtins.property
    @pulumi.getter(name="routeDomain")
    def route_domain(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Specifies the route domain for the OCSP responder.
        """
        return pulumi.get(self, "route_domain")

    @_builtins.property
    @pulumi.getter(name="signHash")
    def sign_hash(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Specifies the hash algorithm used to sign the OCSP request. The default value is `sha256`.
        """
        return pulumi.get(self, "sign_hash")

    @_builtins.property
    @pulumi.getter(name="signerCert")
    def signer_cert(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Specifies the certificate used to sign the OCSP request.
        """
        return pulumi.get(self, "signer_cert")

    @_builtins.property
    @pulumi.getter(name="signerKey")
    def signer_key(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Specifies the key used to sign the OCSP request.
        """
        return pulumi.get(self, "signer_key")

    @_builtins.property
    @pulumi.getter(name="statusAge")
    def status_age(self) -> pulumi.Output[Optional[_builtins.int]]:
        """
        Specifies the maximum allowed lag time that the BIG-IP system accepts for the 'thisUpdate' time in the OCSP response, in seconds. The default value is `0`.
        """
        return pulumi.get(self, "status_age")

    @_builtins.property
    @pulumi.getter(name="strictRespCertCheck")
    def strict_resp_cert_check(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Specifies whether the responder's certificate is checked for an OCSP signing extension. The default value is `enabled`.
        """
        return pulumi.get(self, "strict_resp_cert_check")

    @_builtins.property
    @pulumi.getter(name="trustedResponders")
    def trusted_responders(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Specifies the certificates used for validating the OCSP response.
        """
        return pulumi.get(self, "trusted_responders")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['DataGroupArgs', 'DataGroup']

@pulumi.input_type
class DataGroupArgs:
    def __init__(__self__, *,
                 name: pulumi.Input[_builtins.str],
                 type: pulumi.Input[_builtins.str],
                 internal: Optional[pulumi.Input[_builtins.bool]] = None,
                 records: Optional[pulumi.Input[Sequence[pulumi.Input['DataGroupRecordArgs']]]] = None,
                 records_src: Optional[pulumi.Input[_builtins.str]] = None):
        """
        The set of arguments for constructing a DataGroup resource.
        :param pulumi.Input[_builtins.str] name: Name of the datagroup
        :param pulumi.Input[_builtins.str] type: datagroup type (applies to the `name` field of the record), supports: `string`, `ip` or `integer`
        :param pulumi.Input[_builtins.bool] internal: Set `false` if you want to Create External Datagroups. default is `true`,means creates internal datagroup.
        :param pulumi.Input[Sequence[pulumi.Input['DataGroupRecordArgs']]] records: a set of `name` and `data` attributes, name must be of type specified by the `type` attributed (`string`, `ip` and `integer`), data is optional and can take any value, multiple `record` sets can be specified as needed.
        :param pulumi.Input[_builtins.str] records_src: Path to a file with records in it,The file should be well-formed,it includes records, one per line,that resemble the following format "key separator value". For example, `foo := bar`.
               This should be used in conjunction with `internal` attribute set `false`
        """
        pulumi.set(__self__, "name", name)
        pulumi.set(__self__, "type", type)
        if internal is not None:
            pulumi.set(__self__, "internal", internal)
        if records is not None:
            pulumi.set(__self__, "records", records)
        if records_src is not None:
            pulumi.set(__self__, "records_src", records_src)

    @_builtins.property
    @pulumi.getter
    def name(self) -> pulumi.Input[_builtins.str]:
        """
        Name of the datagroup
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter
    def type(self) -> pulumi.Input[_builtins.str]:
        """
        datagroup type (applies to the `name` field of the record), supports: `string`, `ip` or `integer`
        """
        return pulumi.get(self, "type")

    @type.setter
    def type(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "type", value)

    @_builtins.property
    @pulumi.getter
    def internal(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Set `false` if you want to Create External Datagroups. default is `true`,means creates internal datagroup.
        """
        return pulumi.get(self, "internal")

    @internal.setter
    def internal(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "internal", value)

    @_builtins.property
    @pulumi.getter
    def records(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['DataGroupRecordArgs']]]]:
        """
        a set of `name` and `data` attributes, name must be of type specified by the `type` attributed (`string`, `ip` and `integer`), data is optional and can take any value, multiple `record` sets can be specified as needed.
        """
        return pulumi.get(self, "records")

    @records.setter
    def records(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['DataGroupRecordArgs']]]]):
        pulumi.set(self, "records", value)

    @_builtins.property
    @pulumi.getter(name="recordsSrc")
    def records_src(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Path to a file with records in it,The file should be well-formed,it includes records, one per line,that resemble the following format "key separator value". For example, `foo := bar`.
        This should be used in conjunction with `internal` attribute set `false`
        """
        return pulumi.get(self, "records_src")

    @records_src.setter
    def records_src(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "records_src", value)


@pulumi.input_type
class _DataGroupState:
    def __init__(__self__, *,
                 internal: Optional[pulumi.Input[_builtins.bool]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 records: Optional[pulumi.Input[Sequence[pulumi.Input['DataGroupRecordArgs']]]] = None,
                 records_src: Optional[pulumi.Input[_builtins.str]] = None,
                 type: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering DataGroup resources.
        :param pulumi.Input[_builtins.bool] internal: Set `false` if you want to Create External Datagroups. default is `true`,means creates internal datagroup.
        :param pulumi.Input[_builtins.str] name: Name of the datagroup
        :param pulumi.Input[Sequence[pulumi.Input['DataGroupRecordArgs']]] records: a set of `name` and `data` attributes, name must be of type specified by the `type` attributed (`string`, `ip` and `integer`), data is optional and can take any value, multiple `record` sets can be specified as needed.
        :param pulumi.Input[_builtins.str] records_src: Path to a file with records in it,The file should be well-formed,it includes records, one per line,that resemble the following format "key separator value". For example, `foo := bar`.
               This should be used in conjunction with `internal` attribute set `false`
        :param pulumi.Input[_builtins.str] type: datagroup type (applies to the `name` field of the record), supports: `string`, `ip` or `integer`
        """
        if internal is not None:
            pulumi.set(__self__, "internal", internal)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if records is not None:
            pulumi.set(__self__, "records", records)
        if records_src is not None:
            pulumi.set(__self__, "records_src", records_src)
        if type is not None:
            pulumi.set(__self__, "type", type)

    @_builtins.property
    @pulumi.getter
    def internal(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Set `false` if you want to Create External Datagroups. default is `true`,means creates internal datagroup.
        """
        return pulumi.get(self, "internal")

    @internal.setter
    def internal(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "internal", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Name of the datagroup
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter
    def records(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['DataGroupRecordArgs']]]]:
        """
        a set of `name` and `data` attributes, name must be of type specified by the `type` attributed (`string`, `ip` and `integer`), data is optional and can take any value, multiple `record` sets can be specified as needed.
        """
        return pulumi.get(self, "records")

    @records.setter
    def records(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['DataGroupRecordArgs']]]]):
        pulumi.set(self, "records", value)

    @_builtins.property
    @pulumi.getter(name="recordsSrc")
    def records_src(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Path to a file with records in it,The file should be well-formed,it includes records, one per line,that resemble the following format "key separator value". For example, `foo := bar`.
        This should be used in conjunction with `internal` attribute set `false`
        """
        return pulumi.get(self, "records_src")

    @records_src.setter
    def records_src(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "records_src", value)

    @_builtins.property
    @pulumi.getter
    def type(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        datagroup type (applies to the `name` field of the record), supports: `string`, `ip` or `integer`
        """
        return pulumi.get(self, "type")

    @type.setter
    def type(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "type", value)


@pulumi.type_token("f5bigip:ltm/dataGroup:DataGroup")
class DataGroup(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 internal: Optional[pulumi.Input[_builtins.bool]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 records: Optional[pulumi.Input[Sequence[pulumi.Input[Union['DataGroupRecordArgs', 'DataGroupRecordArgsDict']]]]] = None,
                 records_src: Optional[pulumi.Input[_builtins.str]] = None,
                 type: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        `ltm.DataGroup` Manages internal (in-line) datagroup configuration

        Resource should be named with their`full path`. The full path is the combination of the `partition + name` of the resource, for example `/Common/my-datagroup`.

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.bool] internal: Set `false` if you want to Create External Datagroups. default is `true`,means creates internal datagroup.
        :param pulumi.Input[_builtins.str] name: Name of the datagroup
        :param pulumi.Input[Sequence[pulumi.Input[Union['DataGroupRecordArgs', 'DataGroupRecordArgsDict']]]] records: a set of `name` and `data` attributes, name must be of type specified by the `type` attributed (`string`, `ip` and `integer`), data is optional and can take any value, multiple `record` sets can be specified as needed.
        :param pulumi.Input[_builtins.str] records_src: Path to a file with records in it,The file should be well-formed,it includes records, one per line,that resemble the following format "key separator value". For example, `foo := bar`.
               This should be used in conjunction with `internal` attribute set `false`
        :param pulumi.Input[_builtins.str] type: datagroup type (applies to the `name` field of the record), supports: `string`, `ip` or `integer`
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: DataGroupArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        `ltm.DataGroup` Manages internal (in-line) datagroup configuration

        Resource should be named with their`full path`. The full path is the combination of the `partition + name` of the resource, for example `/Common/my-datagroup`.

        :param str resource_name: The name of the resource.
        :param DataGroupArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(DataGroupArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 internal: Optional[pulumi.Input[_builtins.bool]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 records: Optional[pulumi.Input[Sequence[pulumi.Input[Union['DataGroupRecordArgs', 'DataGroupRecordArgsDict']]]]] = None,
                 records_src: Optional[pulumi.Input[_builtins.str]] = None,
                 type: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = DataGroupArgs.__new__(DataGroupArgs)

            __props__.__dict__["internal"] = internal
            if name is None and not opts.urn:
                raise TypeError("Missing required property 'name'")
            __props__.__dict__["name"] = name
            __props__.__dict__["records"] = records
            __props__.__dict__["records_src"] = records_src
            if type is None and not opts.urn:
                raise TypeError("Missing required property 'type'")
            __props__.__dict__["type"] = type
        super(DataGroup, __self__).__init__(
            'f5bigip:ltm/dataGroup:DataGroup',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            internal: Optional[pulumi.Input[_builtins.bool]] = None,
            name: Optional[pulumi.Input[_builtins.str]] = None,
            records: Optional[pulumi.Input[Sequence[pulumi.Input[Union['DataGroupRecordArgs', 'DataGroupRecordArgsDict']]]]] = None,
            records_src: Optional[pulumi.Input[_builtins.str]] = None,
            type: Optional[pulumi.Input[_builtins.str]] = None) -> 'DataGroup':
        """
        Get an existing DataGroup resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.bool] internal: Set `false` if you want to Create External Datagroups. default is `true`,means creates internal datagroup.
        :param pulumi.Input[_builtins.str] name: Name of the datagroup
        :param pulumi.Input[Sequence[pulumi.Input[Union['DataGroupRecordArgs', 'DataGroupRecordArgsDict']]]] records: a set of `name` and `data` attributes, name must be of type specified by the `type` attributed (`string`, `ip` and `integer`), data is optional and can take any value, multiple `record` sets can be specified as needed.
        :param pulumi.Input[_builtins.str] records_src: Path to a file with records in it,The file should be well-formed,it includes records, one per line,that resemble the following format "key separator value". For example, `foo := bar`.
               This should be used in conjunction with `internal` attribute set `false`
        :param pulumi.Input[_builtins.str] type: datagroup type (applies to the `name` field of the record), supports: `string`, `ip` or `integer`
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _DataGroupState.__new__(_DataGroupState)

        __props__.__dict__["internal"] = internal
        __props__.__dict__["name"] = name
        __props__.__dict__["records"] = records
        __props__.__dict__["records_src"] = records_src
        __props__.__dict__["type"] = type
        return DataGroup(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter
    def internal(self) -> pulumi.Output[Optional[_builtins.bool]]:
        """
        Set `false` if you want to Create External Datagroups. default is `true`,means creates internal datagroup.
        """
        return pulumi.get(self, "internal")

    @_builtins.property
    @pulumi.getter
    def name(self) -> pulumi.Output[_builtins.str]:
        """
        Name of the datagroup
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter
    def records(self) -> pulumi.Output[Optional[Sequence['outputs.DataGroupRecord']]]:
        """
        a set of `name` and `data` attributes, name must be of type specified by the `type` attributed (`string`, `ip` and `integer`), data is optional and can take any value, multiple `record` sets can be specified as needed.
        """
        return pulumi.get(self, "records")

    @_builtins.property
    @pulumi.getter(name="recordsSrc")
    def records_src(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Path to a file with records in it,The file should be well-formed,it includes records, one per line,that resemble the following format "key separator value". For example, `foo := bar`.
        This should be used in conjunction with `internal` attribute set `false`
        """
        return pulumi.get(self, "records_src")

    @_builtins.property
    @pulumi.getter
    def type(self) -> pulumi.Output[_builtins.str]:
        """
        datagroup type (applies to the `name` field of the record), supports: `string`, `ip` or `integer`
        """
        return pulumi.get(self, "type")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['SnmpArgs', 'Snmp']

@pulumi.input_type
class SnmpArgs:
    def __init__(__self__, *,
                 allowedaddresses: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 sys_contact: Optional[pulumi.Input[_builtins.str]] = None,
                 sys_location: Optional[pulumi.Input[_builtins.str]] = None):
        """
        The set of arguments for constructing a Snmp resource.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] allowedaddresses: Configures hosts or networks from which snmpd can accept traffic. Entries go directly into hosts.allow.
        :param pulumi.Input[_builtins.str] sys_contact: Specifies the contact information for the system administrator.
        :param pulumi.Input[_builtins.str] sys_location: Describes the system's physical location.
        """
        if allowedaddresses is not None:
            pulumi.set(__self__, "allowedaddresses", allowedaddresses)
        if sys_contact is not None:
            pulumi.set(__self__, "sys_contact", sys_contact)
        if sys_location is not None:
            pulumi.set(__self__, "sys_location", sys_location)

    @_builtins.property
    @pulumi.getter
    def allowedaddresses(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        Configures hosts or networks from which snmpd can accept traffic. Entries go directly into hosts.allow.
        """
        return pulumi.get(self, "allowedaddresses")

    @allowedaddresses.setter
    def allowedaddresses(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "allowedaddresses", value)

    @_builtins.property
    @pulumi.getter(name="sysContact")
    def sys_contact(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Specifies the contact information for the system administrator.
        """
        return pulumi.get(self, "sys_contact")

    @sys_contact.setter
    def sys_contact(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "sys_contact", value)

    @_builtins.property
    @pulumi.getter(name="sysLocation")
    def sys_location(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Describes the system's physical location.
        """
        return pulumi.get(self, "sys_location")

    @sys_location.setter
    def sys_location(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "sys_location", value)


@pulumi.input_type
class _SnmpState:
    def __init__(__self__, *,
                 allowedaddresses: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 sys_contact: Optional[pulumi.Input[_builtins.str]] = None,
                 sys_location: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering Snmp resources.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] allowedaddresses: Configures hosts or networks from which snmpd can accept traffic. Entries go directly into hosts.allow.
        :param pulumi.Input[_builtins.str] sys_contact: Specifies the contact information for the system administrator.
        :param pulumi.Input[_builtins.str] sys_location: Describes the system's physical location.
        """
        if allowedaddresses is not None:
            pulumi.set(__self__, "allowedaddresses", allowedaddresses)
        if sys_contact is not None:
            pulumi.set(__self__, "sys_contact", sys_contact)
        if sys_location is not None:
            pulumi.set(__self__, "sys_location", sys_location)

    @_builtins.property
    @pulumi.getter
    def allowedaddresses(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        Configures hosts or networks from which snmpd can accept traffic. Entries go directly into hosts.allow.
        """
        return pulumi.get(self, "allowedaddresses")

    @allowedaddresses.setter
    def allowedaddresses(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "allowedaddresses", value)

    @_builtins.property
    @pulumi.getter(name="sysContact")
    def sys_contact(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Specifies the contact information for the system administrator.
        """
        return pulumi.get(self, "sys_contact")

    @sys_contact.setter
    def sys_contact(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "sys_contact", value)

    @_builtins.property
    @pulumi.getter(name="sysLocation")
    def sys_location(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Describes the system's physical location.
        """
        return pulumi.get(self, "sys_location")

    @sys_location.setter
    def sys_location(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "sys_location", value)


@pulumi.type_token("f5bigip:sys/snmp:Snmp")
class Snmp(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 allowedaddresses: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 sys_contact: Optional[pulumi.Input[_builtins.str]] = None,
                 sys_location: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        `sys.Snmp` provides details bout how to enable "ilx", "asm" "apm" resource on BIG-IP
        ## Example Usage

        ```python
        import pulumi
        import pulumi_f5bigip as f5bigip

        snmp = f5bigip.sys.Snmp("snmp",
            sys_contact=" NetOPsAdmin s.shitole@f5.com",
            sys_location="SeattleHQ",
            allowedaddresses=["202.10.10.2"])
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] allowedaddresses: Configures hosts or networks from which snmpd can accept traffic. Entries go directly into hosts.allow.
        :param pulumi.Input[_builtins.str] sys_contact: Specifies the contact information for the system administrator.
        :param pulumi.Input[_builtins.str] sys_location: Describes the system's physical location.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: Optional[SnmpArgs] = None,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        `sys.Snmp` provides details bout how to enable "ilx", "asm" "apm" resource on BIG-IP
        ## Example Usage

        ```python
        import pulumi
        import pulumi_f5bigip as f5bigip

        snmp = f5bigip.sys.Snmp("snmp",
            sys_contact=" NetOPsAdmin s.shitole@f5.com",
            sys_location="SeattleHQ",
            allowedaddresses=["202.10.10.2"])
        ```

        :param str resource_name: The name of the resource.
        :param SnmpArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(SnmpArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 allowedaddresses: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 sys_contact: Optional[pulumi.Input[_builtins.str]] = None,
                 sys_location: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = SnmpArgs.__new__(SnmpArgs)

            __props__.__dict__["allowedaddresses"] = allowedaddresses
            __props__.__dict__["sys_contact"] = sys_contact
            __props__.__dict__["sys_location"] = sys_location
        super(Snmp, __self__).__init__(
            'f5bigip:sys/snmp:Snmp',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            allowedaddresses: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
            sys_contact: Optional[pulumi.Input[_builtins.str]] = None,
            sys_location: Optional[pulumi.Input[_builtins.str]] = None) -> 'Snmp':
        """
        Get an existing Snmp resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] allowedaddresses: Configures hosts or networks from which snmpd can accept traffic. Entries go directly into hosts.allow.
        :param pulumi.Input[_builtins.str] sys_contact: Specifies the contact information for the system administrator.
        :param pulumi.Input[_builtins.str] sys_location: Describes the system's physical location.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _SnmpState.__new__(_SnmpState)

        __props__.__dict__["allowedaddresses"] = allowedaddresses
        __props__.__dict__["sys_contact"] = sys_contact
        __props__.__dict__["sys_location"] = sys_location
        return Snmp(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter
    def allowedaddresses(self) -> pulumi.Output[Optional[Sequence[_builtins.str]]]:
        """
        Configures hosts or networks from which snmpd can accept traffic. Entries go directly into hosts.allow.
        """
        return pulumi.get(self, "allowedaddresses")

    @_builtins.property
    @pulumi.getter(name="sysContact")
    def sys_contact(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Specifies the contact information for the system administrator.
        """
        return pulumi.get(self, "sys_contact")

    @_builtins.property
    @pulumi.getter(name="sysLocation")
    def sys_location(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Describes the system's physical location.
        """
        return pulumi.get(self, "sys_location")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'VlanInterfaceArgs',
    'VlanInterfaceArgsDict',
]

MYPY = False

if not MYPY:
    class VlanInterfaceArgsDict(TypedDict):
        tagged: NotRequired[pulumi.Input[_builtins.bool]]
        """
        Specifies a list of tagged interfaces or trunks associated with this VLAN. Note that you can associate tagged interfaces or trunks with any number of VLANs.
        """
        vlanport: NotRequired[pulumi.Input[_builtins.str]]
        """
        Physical or virtual port used for traffic
        """
elif False:
    VlanInterfaceArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class VlanInterfaceArgs:
    def __init__(__self__, *,
                 tagged: Optional[pulumi.Input[_builtins.bool]] = None,
                 vlanport: Optional[pulumi.Input[_builtins.str]] = None):
        """
        :param pulumi.Input[_builtins.bool] tagged: Specifies a list of tagged interfaces or trunks associated with this VLAN. Note that you can associate tagged interfaces or trunks with any number of VLANs.
        :param pulumi.Input[_builtins.str] vlanport: Physical or virtual port used for traffic
        """
        if tagged is not None:
            pulumi.set(__self__, "tagged", tagged)
        if vlanport is not None:
            pulumi.set(__self__, "vlanport", vlanport)

    @_builtins.property
    @pulumi.getter
    def tagged(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Specifies a list of tagged interfaces or trunks associated with this VLAN. Note that you can associate tagged interfaces or trunks with any number of VLANs.
        """
        return pulumi.get(self, "tagged")

    @tagged.setter
    def tagged(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "tagged", value)

    @_builtins.property
    @pulumi.getter
    def vlanport(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Physical or virtual port used for traffic
        """
        return pulumi.get(self, "vlanport")

    @vlanport.setter
    def vlanport(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "vlanport", value)


